@@ -10,17 +10,15 @@ import (
 	dto "github.com/prometheus/client_model/go"
 )
 
-var (
-	expectedBFDMetrics = map[string]float64{
-		"frr_bfd_peer_count{}": 3,
-		"frr_bfd_peer_uptime{local=10.10.141.81,peer=10.10.141.61}": 847716,
-		"frr_bfd_peer_state{local=10.10.141.81,peer=10.10.141.61}":  1,
-		"frr_bfd_peer_uptime{local=10.10.141.81,peer=10.10.141.62}": 847595,
-		"frr_bfd_peer_state{local=10.10.141.81,peer=10.10.141.62}":  1,
-		"frr_bfd_peer_uptime{local=10.10.141.81,peer=10.10.141.63}": 847888,
-		"frr_bfd_peer_state{local=10.10.141.81,peer=10.10.141.63}":  0,
-	}
-)
+var expectedBFDMetrics = map[string]float64{
+	"frr_bfd_peer_count{}": 3,
+	"frr_bfd_peer_uptime{local=10.10.141.81,peer=10.10.141.61}": 847716,
+	"frr_bfd_peer_state{local=10.10.141.81,peer=10.10.141.61}":  1,
+	"frr_bfd_peer_uptime{local=10.10.141.81,peer=10.10.141.62}": 847595,
+	"frr_bfd_peer_state{local=10.10.141.81,peer=10.10.141.62}":  1,
+	"frr_bfd_peer_uptime{local=10.10.141.81,peer=10.10.141.63}": 847888,
+	"frr_bfd_peer_state{local=10.10.141.81,peer=10.10.141.63}":  0,
+}
 
 func TestProcessBFDPeers(t *testing.T) {
 	ch := make(chan prometheus.Metric, 1024)
@@ -70,7 +68,6 @@ func TestProcessBFDPeers(t *testing.T) {
 			if expectedMetricVal != metricVal {
 				t.Errorf("metric %s expected value %v got %v", metricName, expectedMetricVal, metricVal)
 			}
-
 		} else {
 			t.Errorf("unexpected metric: %s : %v", metricName, metricVal)
 		}
